"""Takes a int (up to 64bits) and returns it as a base 64 encoded string.
"""
import base64


def encode(number):
    """Represent an int as a base64 encoded string.

    >>> encode(8014872923812424107)
    'bzqMdae8aas'
    """
    number_as_bytes = number.to_bytes(8, "big")
    b64_string = base64.urlsafe_b64encode(number_as_bytes).decode("utf-8")

    # We only need the padding '=' for when we are chaining together b64
    # strings.
    return b64_string.rstrip("=")


def decode(b64_string):
    """Extract the int from a b64 encoded string.

    >>> decode('bzqMdae8aas')
    8014872923812424107
    """
    while (len(b64_string) % 4) != 0:
        # We remove the padding in encode for brevity.
        # So we need to add it back here.
        b64_string += "="

    number_as_bytes = base64.urlsafe_b64decode(b64_string)
    return int.from_bytes(number_as_bytes, "big")
